# Qsymm Authors
Below is a list of the contributors to Qsymm:

+ [Anton Akhmerov](<https://antonakhmerov.org>)
+ Tomas Rosdahl
+ Rafal Skolasinski
+ Daniel Varjas
+ [Joseph Weston](https://weston.cloud)

For a full list of contributors run

```
git log --pretty=format:"%an" | sort | uniq
```
